netapp_ontap.models.cluster_nodes_controller_flash_cache API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_controller_flash_cache`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesControllerFlashCacheSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesControllerFlashCache object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `capacity: Size GET`

    Size in bytes

    Example: 1024000000000

  `device_id: Size GET`

    The device_id field of the cluster_nodes_controller_flash_cache.

    Example: 0

  `firmware_file: str GET`

    The firmware_file field of the cluster_nodes_controller_flash_cache.

    Example: X9170_O000Z6300NVM

  `firmware_version: str GET`

    The firmware_version field of the cluster_nodes_controller_flash_cache.

    Example: NA05

  `hardware_revision: str GET`

    The hardware_revision field of the cluster_nodes_controller_flash_cache.

    Example: A1

  `model: str GET`

    The model field of the cluster_nodes_controller_flash_cache.

    Example: X1970A

  `part_number: str GET`

    The part_number field of the cluster_nodes_controller_flash_cache.

    Example: 119-00207

  `serial_number: str GET`

    The serial_number field of the cluster_nodes_controller_flash_cache.

    Example: A22P5061550000187

  `slot: str GET`

    The slot field of the cluster_nodes_controller_flash_cache.

    Example: 6-1

  `state: str GET`

    The state field of the cluster_nodes_controller_flash_cache.

    Valid choices:

    - ok
    - erasing
    - erased
    - failed
    - removed